pygeodesy.triaxials.bases._OrderedTriaxialBase

Package pygeodesy :: Package triaxials :: Module bases :: Class _OrderedTriaxialBase |
[frames] | no frames]

# Class _OrderedTriaxialBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
      _UnOrderedTriaxialBase --+
                               |
                              _OrderedTriaxialBase

Known Subclasses:
  - triaxial5.Triaxial
  - , _Triaxial3Base

(INTERNAL) Base class for all ordered triaxial classes.

Instance Methods
__init__(self, a_triaxial, b=None, c=None, **name) New ordered Triaxial, Triaxial3, Conformal or Conformal3. |
Inherited from `_UnOrderedTriaxialBase`: `areaKT`, `area_p`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| area Get the surface area (`meter` squared).
Inherited from `_UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOblate`, `isOrdered`, `isProlate`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_triaxial, b=None, c=None, **name) (Constructor) |
New ordered Triaxial, Triaxial3, Conformal or Conformal3. Arguments: `a_triaxial` - Largest semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial or Triaxial_ instance. `b` - Middle semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Smallest semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Semi-axes unordered, spherical or invalid. Overrides: object.__init__ Note: The semi-axes must be ordered as `a >= b >= c > 0` and must be ellipsoidal, `a > c`.

Property Details

### area Get the surface area (`meter` squared). Get method: area(self) - Get the surface area (`meter` squared). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Surface area.